#!/bin/bash

LOGDIR="/tmp/buildlog"

TYPE="$1";     shift
NAME="$1";     shift
VERSION="$1";  shift
REVISION="$1"; shift

if [ -z "$TYPE" ] || [ -z "$NAME" ] || [ -z "$VERSION" ] || [ -z "$REVISION" ] || [ -z "$1" ]; then
	echo "usage: $0 <type> <name> <version> <revision> <command> [command-args]"
	exit 0
fi

mkdir -p "$LOGDIR" || :
if [ ! -d "$LOGDIR" ] || [ ! -w "$LOGDIR" ]; then
	"$@"
	exit $?
fi

check_for_failed() {
	if [ -f "$LOGDIR/$NAME-$VERSION-$REVISION.failed" ]; then
		echo "$NAME-$VERSION-$REVISION $TYPE-build failed!"
		rm -rf "$LOGDIR/$NAME-$VERSION-$REVISION.failed"
		exit 1
	fi
}

onint() {
	trap SIGINT
	check_for_failed
	kill -SIGINT $$
}

touch_failed() {
	touch "$LOGDIR/$NAME-$VERSION-$REVISION.failed"
}

trap onint SIGINT
trap onint SIGQUIT
trap SIGTERM

rm -rf "$LOGDIR/$NAME-$VERSION-$REVISION.failed"

date > "$LOGDIR/$NAME-$VERSION-$REVISION.$TYPE"
(trap touch_failed SIGINT; trap touch_failed SIGQUIT; "$@" || touch_failed) 2>&1 | tee -a "$LOGDIR/$NAME-$VERSION-$REVISION.$TYPE" || touch_failed

check_for_failed
